@@ -27,7 +27,7 @@ expect_equal(rs$content_type, "text/html")
 expect_equal(rs$headers, list(Server = getOption("RestRserve.headers.server")))
 expect_equal(rs$status_code, 200L)
 
-# Test Swagger UI assets
+# Test Swagger UI css asset
 rq = Request$new(path = "/swagger/assets/swagger-ui.css")
 rs = app$process_request(rq)
 expect_equal(names(rs$body), "file")
@@ -37,4 +37,22 @@ expect_equal(rs$content_type, "text/css")
 expect_equal(rs$headers, list(Server = getOption("RestRserve.headers.server")))
 expect_equal(rs$status_code, 200L)
 
+# Test Swagger UI js asset
+rq = Request$new(path = "/swagger/assets/swagger-ui-standalone-preset.js")
+rs = app$process_request(rq)
+expect_equal(names(rs$body), "file")
+expect_true(file.exists(rs$body))
+expect_equal(rs$content_type, "application/javascript")
+expect_equal(rs$headers, list(Server = getOption("RestRserve.headers.server")))
+expect_equal(rs$status_code, 200L)
+
+# Test Swagger UI png asset
+rq = Request$new(path = "/swagger/assets/favicon-16x16.png")
+rs = app$process_request(rq)
+expect_equal(names(rs$body), "file")
+expect_true(file.exists(rs$body))
+expect_equal(rs$content_type, "image/png")
+expect_equal(rs$headers, list(Server = getOption("RestRserve.headers.server")))
+expect_equal(rs$status_code, 200L)
+
 cleanup_app()
