@@ -28,7 +28,7 @@ std::string url_encode_one(const std::string& value) {
 }
 
 // [[Rcpp::export]]
-Rcpp::CharacterVector url_encode(Rcpp::CharacterVector x) {
+Rcpp::CharacterVector cpp_url_encode(Rcpp::CharacterVector x) {
   std::size_t n = x.size();
   Rcpp::CharacterVector out = Rcpp::no_init(n);
   for (std::size_t i = 0; i < n; ++i) {
